library(testthat)
library(CDECRetrieve)

test_check("CDECRetrieve")
